### 0.12.1 {small}`2025-03-10`

```{rubric} Features
```
* Adds `nn_descent` algorithm for `pp.neighbors` {pr}`325` {smaller}`S Dicks`
* Adds `theta` to `tl.leiden` {pr}`338` {smaller}`S Dicks`

```{rubric} Bug fixes
```
* Fixes a bug with `tl.kmeans` {pr}`338` {smaller}`S Dicks`

```{rubric} Misc
```
* Updates Notebooks {pr}`325` {smaller}`S Dicks`
* Adds support for `rapids-25.02` {pr}`329` {smaller}`S Dicks`
* Updates the docker for `rapids-25.02` {pr}`329` {smaller}`S Dicks`
* Handles logging for `rapids-25.02` {pr}`337` {smaller}`S Dicks`
